@@ -68,7 +68,7 @@ class LineReader(object):
     if self.file == sys.stdin:
       self.current = self.current.decode('utf-8')
     self.linenumber += 1
-    Trace.prefix = 'Line ' + str(self.linenumber) + ': '
+    Trace.prefix = 'Line ' + unicode(self.linenumber) + ': '
     if self.linenumber % 1000 == 0:
       Trace.message('Parsing')
 
@@ -93,6 +93,9 @@ class LineWriter(object):
   def write(self, strings):
     "Write a list of strings"
     for string in strings:
+      if not isinstance(string, basestring):
+        Trace.error('Not a string: ' + unicode(string) + ' in ' + unicode(strings))
+        return
       self.writestring(string)
 
   def writestring(self, string):
