@@ -41,9 +41,11 @@ class Options(object):
   html = False
   help = False
   showlines = True
+  unicode = False
   css = 'http://www.nongnu.org/elyxer/lyx.css'
-  title = 'Converted document'
+  title = None
   directory = '.'
+  toc = False
   branches = dict()
 
   def parseoptions(self, args):
@@ -74,9 +76,11 @@ class Options(object):
     Trace.error('    --quiet: disables all runtime messages')
     Trace.error('    --debug: enable debugging messages (for developers)')
     Trace.error('    --title <title>: set the generated page title')
+    Trace.error('    --directory <images_dir>: look for images in the specified directory')
     Trace.error('    --css <file.css>: use a custom CSS file')
     Trace.error('    --version: show version number and release date')
     Trace.error('    --html: output HTML 4.0 instead of the default XHTML')
+    Trace.error('    --unicode: full Unicode output')
     exit()
 
   def showversion(self):
